==> agnostos-0.9.7.tar.gz: agnostos/agnostos_docroot/view_tasks.pl <==
#!/usr/bin/perl -w 

# Copyright (C) 2000 Julian T. J. Midgley <jtjm@xenoclast.org>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# A copy of version 2 of the GNU General Public License may be found
# in the file "LICENCE" in the original Agnostos installation driectory.


use taskman_lib;
use strict;
use CGI;

# Parameters passed:
# table : tablename
# id    : id within the table whose entries are to be displayed



#--------------------------------------------------------------------------
# dispview ($table, $id, $show_cancelled, $sortby)
#
# displays the view for the requested 'user'.  $table should be set to
# one of 'workgroup', 'user', or 'department'.

sub
dispview 
{
    my ($tableref, $show_cancelled, $sortby, $order) = @_;
    my $first = 0;
    $show_cancelled = 'false' unless (defined $show_cancelled);
    # Ordering  $order = 1 => Ascending
    #           $order = 0 => Descending
    unless (defined $order) {
	$order = 1;
	$first = 1;
    }
    
    #my $assid = gen_assigned_name($table);
    my $dbh1 = dbserver_connect('agnostos');
    my ($dbq1, $todoid, $title, $priority, $status, $numrows, $sql_query, %users, %groups, %depts);
    my ($userid, $groupid, $depid, $date, $row, $td, $overdue);
    my $tablehead="#efea9e";         # Background colour of headings
    my $tableheadcol="#ffffff";      # Text colour of headings
    my @col_row=("#f1f3e9","#dfd7c9");
    my @col_inprog=("#78c653","#9ee27f");
    my @col_overdue=("#f40e0e","#e03e3e");
    my @col_done=("#90ccf9","#5ab1f4",);
    #my @col_queued=("#03b206","#58d310");
    #my @col_inprog=@col_row;
    my @col_queued=@col_row;
    
    %users  = fetch_ents( 'user',       $dbh1);
    %groups = fetch_ents( 'workgroup',  $dbh1);
    %depts  = fetch_ents( 'department', $dbh1);
    
    $sql_query = "SELECT todo.todoid, title, priority, status, 
                         assigned.userid, assigned.groupid, assigned.depid, date, 
                         (TO_DAYS(date)-TO_DAYS(CURDATE())) 
                     FROM todo, assigned 
                     WHERE todo.todoid = assigned.todoid ";
    my $asstable;
    foreach $asstable (keys %$tableref) {
	my $assigned_table = gen_assigned_name($asstable);
	$sql_query .= "AND assigned.$assigned_table = $$tableref{$asstable} ";
    }
    unless ($show_cancelled eq "true") {
	$sql_query .=  "AND status != 'cancelled' AND status != 'done' ";
    }
    my $direction;
    if ($order) {
	$direction = "ASC";
    }
    else {
	$direction = "DESC";
    }
    if ($sortby eq "status") {
	$sql_query .= " ORDER BY status $direction,priority,date";
    }
    elsif ($sortby eq "priority") {
	$sql_query .= " ORDER BY priority $direction,status,date";
    }
    elsif ($sortby eq "date") {
	$sql_query .= " ORDER BY date $direction,status,priority";
    }
    else {
	$sql_query .= " ORDER BY status,priority,date";
    }
    $dbq1 = $dbh1 ->prepare($sql_query);
    $numrows = $dbq1 -> execute;
    if ( $numrows > 0 ) {
	$order = $order ? 0 : 1;
	$td = "<td bgcolor=$tablehead>";
	print "<table><tr>$td<b>ID</b>$td<b>Task</b>\n";
	print "$td<b><a href=\"view_tasks.pl?sortby=priority&order=$order\">Priority</a></b>\n";
	if ($first) {
	    # The default order for status and date is the opposite of that for priority,
            # so invert it if this is the first time the page has been displayed.
	    $order = $order ? 0 : 1;
	}
	print "$td<b><a href=\"view_tasks.pl?sortby=status&order=$order\">Status</a></b>\n";
	print "$td<b>User</b>$td<b>Group</b>$td<b>Department</b>\n";
	print "$td<b><a href=\"view_tasks.pl?sortby=date&order=$order\">Due Date</a></b>\n";
	$row = 0;
	while ( ($todoid, $title, $priority, $status, $userid, $groupid, $depid, $date, $overdue) = $dbq1 -> fetchrow_array ) {
	    if ($sortby eq 'date' && ! defined $date) {
		next;
	    }
	    $row = $row ? 0 : 1 ;
	    if ($status eq 'in-progress') {
		$td = $col_inprog[$row];
	    }
	    elsif ($status eq 'queued') {
		$td = $col_queued[$row];
	    }
	    elsif ($status eq 'done' or $status eq 'cancelled') {
		$td = $col_done[$row];
	    }
	    else {
		$td = $col_row[$row];
	    }
	    if (defined $overdue && $overdue < 0) {
		$td = $col_overdue[$row];
	    }
	    $td = "<td bgcolor=$td>";
	    print "<tr>$td<a href=\"edit_task.pl?todoid=$todoid\">$todoid";
	    print "$td$title$td$priority$td$status\n";
	    if (defined $date && $date =~ /(\d+)-(\d+)-(\d+)/) {
		$date = "$3-$2-$1";
	    }
	    else {
		$date = "";
	    }
	    
	    if ( $userid == 1 ) {
		print "$td$users{$userid}";
	    }
	    else {
		print "$td<a href=\"view_tasks.pl?table=user&id=$userid\">$users{$userid}</a>";
	    }
	    if ( $groupid == 1 ) {
		print "$td$groups{$groupid}";
	    }
	    else {
		print "$td<a href=\"view_tasks.pl?table=workgroup&id=$groupid\">$groups{$groupid}</a>";
	    }
	    if ( $depid == 1 ) {
		print "$td$depts{$depid}";
	    }
	    else {
		print "$td<a href=\"view_tasks.pl?table=department&id=$depid\">$depts{$depid}</a>";
	    }
	    print "$td$date\n";
	    print "<td><a href=\"view_audit.pl?todoid=$todoid\">".
		  "<img border=0 src=\"magglass.png\" alt=\"audit trail\"></a>";
	}
	print "</table>\n";
    }
    $dbq1 -> finish;
    $dbh1 -> disconnect;
    return;
}

#--------------------------------------------------------------------------
# check_setview
#
# Reads the parameters passed to the CGI and returns appropriate
# $table and $id settings.

sub
check_setview 
{
    my $query = new CGI;
    my $user       = $query -> param('user');
    my $workgroup  = $query -> param('workgroup');
    my $dept       = $query -> param('department');
    my $orig_table = $query -> param('table');
    my $orig_id    = $query -> param('id');
    my ( $res_table, $res_id );
    my %table;
    my $found = 0;

    if (defined $user) {
	unless ($user =~ /_1$/) {
	    $user =~ /(.*)_(.*)/;
	    ( $res_table, $res_id ) = ( $1, $2 );
	    $table{$res_table} = $res_id;
	    $found = 1;
	}
    }
    if (defined $workgroup) {
	unless ($workgroup =~ /_1$/) {
	    $workgroup =~ /(.*)_(.*)/;
	    ( $res_table, $res_id ) = ( $1, $2 );
	    $table{$res_table} = $res_id;
	    $found = 1;
	}
    }
    if (defined $dept) {
	unless ($dept =~ /_1$/) {
	    $dept =~ /(.*)_(.*)/;
	    ( $res_table, $res_id ) = ( $1, $2 );
	    $table{$res_table} = $res_id;
	$found = 1;
	}
    }
    unless ($found) {
	unless (defined $orig_table) {
	    $table{'fubar'} = 'completely';
	}
	else {
	    $table{$orig_table} = $orig_id;
	}
    }
    return \%table;
}
    
#--------------------------------------------------------------------------
# main

my $query = new CGI;
my $dbh   = dbserver_connect('agnostos');
#my $table = $query -> param('table');
#my $id    = $query -> param('id');
my ($dbq, $ent_name, $table, $id, $cookie, $tableref);
my $show_cancelled = $query -> param('cancelled');
my $sortby         = $query -> param('sortby');
my $order      = $query -> param('order');

if (!defined $sortby ) {
    $sortby = 'status';
}
$tableref = check_setview();
if (defined $$tableref{'fubar'} && $$tableref{'fubar'} eq 'completely' ) {
    $tableref = get_cookie ($query);
}

else {
    $cookie = set_cookie($tableref, $query);
}


if (defined $$tableref{'fubar'} && $$tableref{'fubar'} eq 'completely' ) {
    print html_header("No view selected",$query);
    print "<h1>Error - no view selected</h1>".
	"You must select a view from the front page.<p>  Once you have done so, a cookie will".
	" be set, and you can then use the &quot;View Tasks&quot; link.";
    print html_footer;
    $dbh -> disconnect;
    exit 0;
}

my $ent_table;
$ent_name = "";
foreach $ent_table (keys %$tableref) {
    my ($act_id, $act_name) = get_table($ent_table);
    $dbq = $dbh -> prepare("SELECT $act_name FROM $ent_table WHERE $act_id = $$tableref{$ent_table}");
    $dbq -> execute;
    if (length($ent_name) > 0) {
	$ent_name .= " &amp; ";
    }
    $ent_name .= $dbq -> fetchrow_array;
    $dbq -> finish;
}    

print html_header("Tasklist for $ent_name", $query, $cookie);
print "<h2>Tasklist for $ent_name</h2><p>";

print "<table><tr><td><a href=\"edit_task.pl\">Add new entry</a></td><td>&nbsp;|&nbsp;</td>";
if (defined $show_cancelled && $show_cancelled eq 'true' ) {
    print  "<td><a href=\"view_tasks.pl\">Hide Done/Cancelled Items</a></td></tr></table>\n";
}
else {
    print  "<td><a href=\"view_tasks.pl?cancelled=true\">Show Done/Cancelled Items</a></td></tr></table>\n";
}

dispview($tableref, $show_cancelled, $sortby, $order);


print html_footer;

$dbh -> disconnect;

==> agnostos-0.9.10.tar.gz: agnostos/agnostos_docroot/view_tasks.pl <==
#!/usr/bin/perl -w 

# Copyright (C) 2000 Julian T. J. Midgley <jtjm@xenoclast.org>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# A copy of version 2 of the GNU General Public License may be found
# in the file "LICENCE" in the original Agnostos installation driectory.


use taskman_lib;
use strict;
use CGI;
use CGI::Carp qw(fatalsToBrowser);

# Parameters passed:
# table : tablename
# id    : id within the table whose entries are to be displayed



#--------------------------------------------------------------------------
# dispview ($table, $id, $show_cancelled, $sortby)
#
# displays the view for the requested 'user'.  $table should be set to
# one of 'workgroup', 'user', or 'department'.

sub
dispview 
{
    my ($tableref, $show_cancelled, $sortby, $order, $config_ref) = @_;
    my $first = 0;
    $show_cancelled = 'false' unless (defined $show_cancelled);
    # Ordering  $order = 1 => Ascending
    #           $order = 0 => Descending
    unless (defined $order) {
	$order = 1;
	$first = 1;
    }

    my ($sep,@date_format) = parse_date_format($config_ref);
    #my $assid = gen_assigned_name($table);
    my $dbh1 = dbserver_connect($config_ref);
    my ($dbq1, $todoid, $title, $priority, $status, $numrows, $sql_query, %users, %groups, %depts);
    my ($userid, $groupid, $depid, $date, $row, $td, $overdue);
    my $tablehead="#efea9e";         # Background colour of headings
    my $tableheadcol="#ffffff";      # Text colour of headings
    my @col_row=("#f1f3e9","#dfd7c9");
    my @col_inprog=("#78c653","#9ee27f");
    my @col_overdue=("#f40e0e","#e03e3e");
    my @col_done=("#90ccf9","#5ab1f4",);
    #my @col_queued=("#03b206","#58d310");
    #my @col_inprog=@col_row;
    my @col_queued=@col_row;
    
    %users  = fetch_ents( 'user',       $dbh1);
    %groups = fetch_ents( 'workgroup',  $dbh1);
    %depts  = fetch_ents( 'department', $dbh1);
    
    $sql_query = "SELECT todo.todoid, title, priority, status, 
                         assigned.userid, assigned.groupid, assigned.depid, date, 
                         (TO_DAYS(date)-TO_DAYS(CURDATE())) 
                     FROM todo, assigned 
                     WHERE todo.todoid = assigned.todoid ";
    my $asstable;
    foreach $asstable (keys %$tableref) {
	my $assigned_table = gen_assigned_name($asstable);
	$sql_query .= "AND assigned.$assigned_table = $$tableref{$asstable} ";
    }
    unless ($show_cancelled eq "true") {
	$sql_query .=  "AND status != 'cancelled' AND status != 'done' ";
    }
    else {
	$sql_query .= "AND ((status != 'cancelled' AND status != 'done') 
                            OR ((status = 'cancelled' OR status = 'done')
                                AND ((TO_DAYS(CURDATE()) - TO_DAYS(completed_date)) 
                                     < $$config_ref{tasks_done_days}))) ";
    }
    my $direction;
    $direction = $order ? "ASC" : "DESC";
   
    if ($sortby eq "status") {
	$sql_query .= " ORDER BY status $direction,priority,date";
    }
    elsif ($sortby eq "priority") {
	$sql_query .= " ORDER BY priority $direction,status,date";
    }
    elsif ($sortby eq "date") {
	$sql_query .= " ORDER BY date $direction,status,priority";
    }
    else {
	$sql_query .= " ORDER BY status,priority,date";
    }
    $dbq1 = $dbh1 ->prepare($sql_query);
    $numrows = $dbq1 -> execute;
    if ( $numrows > 0 ) {
	$order = $order ? 0 : 1;
	$td = "<td bgcolor=$tablehead>";
	print "<table><tr>$td<b>ID</b>$td<b>Task</b>\n";
	print "$td<b><a href=\"view_tasks.pl?sortby=priority&order=$order\">Priority</a></b>\n";
	if ($first) {
	    # The default order for status and date is the opposite of that for priority,
            # so invert it if this is the first time the page has been displayed.
	    $order = $order ? 0 : 1;
	}
	print "$td<b><a href=\"view_tasks.pl?sortby=status&order=$order\">Status</a></b>\n";
	print "$td<b>User</b>$td<b>Group</b>$td<b>Department</b>\n";
	print "$td<b><a href=\"view_tasks.pl?sortby=date&order=$order\">Due Date</a></b>\n";
	$row = 0;
	while ( ($todoid, $title, $priority, $status, $userid, $groupid, $depid, $date, $overdue) = $dbq1 -> fetchrow_array ) {
	    if ($sortby eq 'date' && ! defined $date) {
		next;
	    }
	    $row = $row ? 0 : 1 ;
	    if ($status eq 'in-progress') {
		$td = $col_inprog[$row];
	    }
	    elsif ($status eq 'queued') {
		$td = $col_queued[$row];
	    }
	    elsif ($status eq 'done' or $status eq 'cancelled') {
		$td = $col_done[$row];
	    }
	    else {
		$td = $col_row[$row];
	    }
	    if (defined $overdue && $overdue < 0) {
		$td = $col_overdue[$row];
	    }
	    $td = "<td bgcolor=$td>";
	    print "<tr>$td<a href=\"edit_task.pl?todoid=$todoid\">$todoid";
	    print "$td$title$td$priority$td$status\n";
	    if (defined $date && $date =~ /(\d+)-(\d+)-(\d+)/) {
		$date = format_text_date($3,$2,$1,$sep,@date_format); # "$3-$2-$1";
	    }
	    else {
		$date = "";
	    }
	    
	    if ( $userid == 1 ) {
		print "$td$users{$userid}";
	    }
	    else {
		print "$td<a href=\"view_tasks.pl?table=user&id=$userid\">$users{$userid}</a>";
	    }
	    if ( $groupid == 1 ) {
		print "$td$groups{$groupid}";
	    }
	    else {
		print "$td<a href=\"view_tasks.pl?table=workgroup&id=$groupid\">$groups{$groupid}</a>";
	    }
	    if ( $depid == 1 ) {
		print "$td$depts{$depid}";
	    }
	    else {
		print "$td<a href=\"view_tasks.pl?table=department&id=$depid\">$depts{$depid}</a>";
	    }
	    print "$td$date\n";
	    print "<td><a href=\"view_audit.pl?todoid=$todoid\">".
		  "<img border=0 src=\"img/magglass.png\" alt=\"audit trail\"></a>";
	}
	print "</table>\n";
    }
    $dbq1 -> finish;
    $dbh1 -> disconnect;
    return;
}

#--------------------------------------------------------------------------
# check_setview
#
# Reads the parameters passed to the CGI and returns appropriate
# $table and $id settings.

sub
check_setview 
{
    my $query = new CGI;
    my $user       = $query -> param('user');
    my $workgroup  = $query -> param('workgroup');
    my $dept       = $query -> param('department');
    my $orig_table = $query -> param('table');
    my $orig_id    = $query -> param('id');
    my %table;  # $table{<table_name>} = <database_id>

    my $ftable;

    foreach $ftable ( \$user, \$workgroup, \$dept ) {
	if ( (defined $$ftable)  &&  ($$ftable !~ /_1$/) ) {
	    $$ftable =~ /(.*)_(.*)/;
	    $table{$1} = $2;
	}
    }

    unless (%table) {
	unless (defined $orig_table) {
	    $table{'fubar'} = 'completely';
	}
	else {
	    $table{$orig_table} = $orig_id;
	}
    }
    return \%table;
}
    
#--------------------------------------------------------------------------
# main

my $query = new CGI;
my %config         = get_config();
my $dbh            = dbserver_connect(\%config);
my ($dbq, $ent_name, $table, $id, $cookie, $tableref);
my $show_cancelled = $query -> param('cancelled');
my $sortby         = $query -> param('sortby');
my $order          = $query -> param('order');


if (!defined $sortby ) {
    $sortby = 'status';
}
$tableref = check_setview();
if (defined $$tableref{'fubar'} && $$tableref{'fubar'} eq 'completely' ) {
    $tableref = get_cookie ($query);
}

else {
    $cookie = set_cookie($tableref, $query, \%config);
}


if (defined $$tableref{'fubar'} && $$tableref{'fubar'} eq 'completely' ) {
    print html_header("No view selected",$query);
    print "<h1>Error - no view selected</h1>".
	"You must select a view from the front page.<p>  Once you have done so, a cookie will".
	" be set, and you can then use the &quot;View Tasks&quot; link.";
    print html_footer;
    $dbh -> disconnect;
    exit 0;
}

$ent_name = get_ent_names($tableref,$dbh);
 
print html_header("Tasklist for $ent_name", $query, $cookie);
#print "<h2>Tasklist for $ent_name</h2><p>";
print "<center>". 
      sel_table_html("View Tasks",$tableref, $dbh, \%config).
      "</center><p>\n";

print "<table><tr><td><a href=\"edit_task.pl\">Add new entry</a></td><td>&nbsp;|&nbsp;</td>";
if (defined $show_cancelled && $show_cancelled eq 'true' ) {
    print  "<td><a href=\"view_tasks.pl\">Hide Done/Cancelled Items</a></td></tr></table>\n";
}
else {
    print  "<td><a href=\"view_tasks.pl?cancelled=true\">Show Done/Cancelled Items</a></td></tr></table>\n";
}

dispview($tableref, $show_cancelled, $sortby, $order, \%config);
parse_date_format(\%config);

print html_footer;

$dbh -> disconnect;
